@@ -1,28 +1,10 @@
-# Copyright (c) 2022, Riverbank Computing Limited
-# All rights reserved.
-#
-# This copy of SIP is licensed for use under the terms of the SIP License
-# Agreement.  See the file LICENSE for more details.
-#
-# This copy of SIP may also used under the terms of the GNU General Public
-# License v2 or v3 as published by the Free Software Foundation which can be
-# found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
-#
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
-# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
-# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
-# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
-# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
-# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
-# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-# POSSIBILITY OF SUCH DAMAGE.
+# SPDX-License-Identifier: BSD-2-Clause
+
+# Copyright (c) 2024 Phil Thompson <phil@riverbankcomputing.com>
 
 
-from .specification import (ArgumentType, CachedName, IfaceFile, IfaceFileType,
-        ScopedName)
+from .scoped_name import ScopedName
+from .specification import ArgumentType, CachedName, IfaceFile, IfaceFileType
 
 
 def append_iface_file(iface_file_list, iface_file):
@@ -294,6 +276,13 @@ _PY_AUTO = (ArgumentType.BOOL, ArgumentType.BYTE, ArgumentType.SBYTE,
 _PY_CONSTRAINED = (ArgumentType.CBOOL, ArgumentType.CINT, ArgumentType.CFLOAT,
         ArgumentType.CDOUBLE)
 
+
+def py_as_int(type):
+    """ Return True if Python will interpret a type as int. """
+
+    return type.type in _PY_INT or type.type in _PY_LONG or type.type in _PY_ULONG
+
+
 def same_argument_type(spec, arg1, arg2, strict=True):
     """ Compare two argument types and return True if they are the same.
     'strict' means as C++ would see it, rather than Python.
@@ -496,3 +485,15 @@ def search_typedefs(spec, cpp_name, type):
     # Remember the original typedef.
     if type.original_typedef is None:
         type.original_typedef = typedef
+
+        
+def abi_version_check(spec, min_12, min_13):
+    """ Return True if the ABI version meets minimum version requirements. """
+
+    return spec.abi_version >= min_13 or (min_12 <= spec.abi_version < (13, 0))
+
+
+def abi_has_deprecated_message(spec):
+    """ Return True if the ABI implements sipDeprecated() with a message. """
+
+    return abi_version_check(spec, (12, 16), (13, 9))
